@@ -40,15 +40,15 @@ class UnTagResourcesRequest(RpcRequest):
 	def get_ResourceIds(self):
 		return self.get_query_params().get('ResourceIds')
 
-	def set_ResourceIds(self,ResourceIds):
-		for i in range(len(ResourceIds)):	
-			if ResourceIds[i] is not None:
-				self.add_query_param('ResourceId.' + str(i + 1) , ResourceIds[i]);
+	def set_ResourceIds(self, ResourceIds):
+		for depth1 in range(len(ResourceIds)):
+			if ResourceIds[depth1] is not None:
+				self.add_query_param('ResourceId.' + str(depth1 + 1) , ResourceIds[depth1])
 
 	def get_TagKeys(self):
 		return self.get_query_params().get('TagKeys')
 
-	def set_TagKeys(self,TagKeys):
-		for i in range(len(TagKeys)):	
-			if TagKeys[i] is not None:
-				self.add_query_param('TagKey.' + str(i + 1) , TagKeys[i]);
\ No newline at end of file
+	def set_TagKeys(self, TagKeys):
+		for depth1 in range(len(TagKeys)):
+			if TagKeys[depth1] is not None:
+				self.add_query_param('TagKey.' + str(depth1 + 1) , TagKeys[depth1])
\ No newline at end of file
